==> react-cover-basic-1.18.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import cx from 'classnames';
import Button from '@s-ui/react-atom-button';
var baseClass = 'sui-CoverBasic';

var CoverBasic =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(CoverBasic, _Component);

  function CoverBasic() {
    var _cx, _cx2;

    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.coverBasicClassNames = cx(baseClass, (_cx = {}, _cx[baseClass + "--gradient"] = _this.props.gradient, _cx), (_cx2 = {}, _cx2[baseClass + "--bgImage"] = _this.props.src, _cx2), {
      'is-clickable': !!_this.props.handleClick
    });

    _this._buildButtons = function () {
      var buttons = _this.props.buttons;

      var executeCallback = function executeCallback(e, callback) {
        e.stopPropagation();
        callback(e);
      };

      return buttons.map(function (_ref, index) {
        var Icon = _ref.icon,
            label = _ref.label,
            handleClick = _ref.handleClick;
        return React.createElement("div", {
          className: baseClass + "-button",
          key: index
        }, React.createElement(Button, {
          type: "tertiary",
          leftIcon: Icon && React.createElement(Icon, {
            className: baseClass + "-buttonIcon"
          }),
          onClick: function onClick(e) {
            return executeCallback(e, handleClick);
          }
        }, label));
      });
    };

    _this.buttons = _this._buildButtons();
    return _this;
  }

  var _proto = CoverBasic.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        src = _this$props.src,
        height = _this$props.height;
    var backgroundImage = "url(" + src + ")";
    var styles = {
      backgroundImage: backgroundImage,
      height: height
    };
    return React.createElement("div", {
      className: this.coverBasicClassNames,
      onClick: this.props.handleClick,
      style: styles
    }, this.props.children && React.createElement("div", {
      className: baseClass + "-children"
    }, this.props.children), this.buttons.length > 0 && React.createElement("div", {
      className: baseClass + "-buttonList"
    }, this.buttons));
  };

  return CoverBasic;
}(Component);

CoverBasic.displayName = 'CoverBasic';
CoverBasic.defaultProps = {
  buttons: [],
  gradient: false
};
export default CoverBasic;

==> react-cover-basic-1.19.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { Component } from 'react';
import cx from 'classnames';
import Button from '@s-ui/react-atom-button';
var baseClass = 'sui-CoverBasic';

var CoverBasic = /*#__PURE__*/function (_Component) {
  _inheritsLoose(CoverBasic, _Component);

  function CoverBasic() {
    var _cx, _cx2;

    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.coverBasicClassNames = cx(baseClass, (_cx = {}, _cx[baseClass + "--gradient"] = _this.props.gradient, _cx), (_cx2 = {}, _cx2[baseClass + "--bgImage"] = _this.props.src, _cx2), {
      'is-clickable': !!_this.props.handleClick
    });

    _this._buildButtons = function () {
      var buttons = _this.props.buttons;

      var executeCallback = function executeCallback(e, callback) {
        e.stopPropagation();
        callback(e);
      };

      return buttons.map(function (_ref, index) {
        var Icon = _ref.icon,
            label = _ref.label,
            handleClick = _ref.handleClick;
        return /*#__PURE__*/_jsx("div", {
          className: baseClass + "-button",
          children: /*#__PURE__*/_jsx(Button, {
            type: "tertiary",
            leftIcon: Icon && /*#__PURE__*/_jsx(Icon, {
              className: baseClass + "-buttonIcon"
            }),
            onClick: function onClick(e) {
              return executeCallback(e, handleClick);
            },
            children: label
          })
        }, index);
      });
    };

    _this.buttons = _this._buildButtons();
    return _this;
  }

  var _proto = CoverBasic.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        src = _this$props.src,
        height = _this$props.height;
    var backgroundImage = "url(" + src + ")";
    var styles = {
      backgroundImage: backgroundImage,
      height: height
    };
    return /*#__PURE__*/_jsxs("div", {
      className: this.coverBasicClassNames,
      onClick: this.props.handleClick,
      style: styles,
      children: [this.props.children && /*#__PURE__*/_jsx("div", {
        className: baseClass + "-children",
        children: this.props.children
      }), this.buttons.length > 0 && /*#__PURE__*/_jsx("div", {
        className: baseClass + "-buttonList",
        children: this.buttons
      })]
    });
  };

  return CoverBasic;
}(Component);

CoverBasic.displayName = 'CoverBasic';
CoverBasic.defaultProps = {
  buttons: [],
  gradient: false
};
export default CoverBasic;
